@@ -24,12 +24,12 @@
 ##
 ##  Set 'GAP_DIR' to the name of the directory where you have installed  GAP,
 ##  i.e., the directory with the subdirectories  'lib',  'grp',  'doc',  etc.
-##  The default is '/build/gap/src/gap-4.10.0',  which is the root directory if you install
+##  The default is '/build/gap/src/gap-4.10.1',  which is the root directory if you install
 ##  XGAP in the default `pkg' directory.
 ##  If you install XGAP in a private directory you have to change this.
 ##
 if [ "x$GAP_DIR" = "x" ];  then
-GAP_DIR="/build/gap/src/gap-4.10.0"
+GAP_DIR="/build/gap/src/gap-4.10.1"
 fi
 
 
@@ -44,7 +44,7 @@ fi
 ##  the 'bin' directory.
 ##
 if [ "x$GAP_PRG" = "x" ];  then
-GAP_PRG=armv5tel-unknown-linux-gnueabi-default32/gap
+GAP_PRG=armv5tel-unknown-linux-gnueabi-default32-kv3/gap
 fi
 
 
@@ -228,7 +228,7 @@ fi;
 #############################################################################
 ##
 ##
-XGAP=/build/gap/src/gap-4.10.0/pkg/xgap-4.28/bin/$XGAP_PRG
+XGAP=/build/gap/src/gap-4.10.1/pkg/xgap-4.29/bin/$XGAP_PRG
 GAP=$GAP_DIR/bin/$GAP_PRG
 
 #############################################################################
